@@ -9,7 +9,7 @@ use IO::Socket;
 use IO::Select;
 use Net::IMAP::Simple::PipeSocket;
 
-our $VERSION = "1.2025";
+our $VERSION = "1.2026";
 
 BEGIN {
     # I'd really rather the pause/cpan indexers miss this "package"
@@ -525,7 +525,7 @@ sub search {
     # add rfc5256 sort, requires charset :(
     if ($sort) {
         $sort = uc $sort;
-        $cmd = "SORT ($sort) \"$charset\"";
+        $cmd = ($uidm ? "UID ": "") . "SORT ($sort) \"$charset\"";
     }
 
     my @seq;
